@@ -24,11 +24,12 @@
 #endif
 
 /**
- * SECTION:jsonrpc-version
- * @short_description: libide version checking
+ * SECTION:ide-version
+ * @title: Version Checking
+ * @short_description: Conditionally include code based on Builder version
  *
- * libide provides macros to check the version of the library
- * at compile-time
+ * This module provides various macros that may be used to build code based
+ * on the version of Builder at build time.
  */
 
 /**
@@ -36,7 +37,7 @@
  *
  * The build type of the installed build.
  */
-#define IDE_BUILD_TYPE "release"
+#define IDE_BUILD_TYPE "debugoptimized"
 
 /**
  * IDE_BUILD_CHANNEL:
@@ -58,21 +59,21 @@
  *
  * libide minor version component (e.g. 2 if %IDE_VERSION is 1.2.3)
  */
-#define IDE_MINOR_VERSION (26)
+#define IDE_MINOR_VERSION (30)
 
 /**
  * IDE_MICRO_VERSION:
  *
  * libide micro version component (e.g. 3 if %IDE_VERSION is 1.2.3)
  */
-#define IDE_MICRO_VERSION (2)
+#define IDE_MICRO_VERSION (0)
 
 /**
  * IDE_VERSION
  *
  * libide version.
  */
-#define IDE_VERSION (3.26.2)
+#define IDE_VERSION (3.30.0)
 
 /**
  * IDE_VERSION_S:
@@ -80,7 +81,7 @@
  * libide version, encoded as a string, useful for printing and
  * concatenation.
  */
-#define IDE_VERSION_S "3.26.2"
+#define IDE_VERSION_S "3.30.0"
 
 #define IDE_ENCODE_VERSION(major,minor,micro) \
         ((major) << 24 | (minor) << 16 | (micro) << 8)
